==> ZenTaoPMS.16.5.php7.2_7.4.zip: zentaopms/extension/biz/feedback/lang/en.php <==
<?php
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Category';
$lang->feedback->moduleAB          = 'Category';
$lang->feedback->manageCate        = 'Manage Category';
$lang->feedback->index             = 'Feedback Home';
$lang->feedback->create            = 'Add Feedback';
$lang->feedback->edit              = 'Edit Feedback';
$lang->feedback->createFaq         = 'Add FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Feedback Interface';
$lang->feedback->browse            = 'Feedback List';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'Feedback Detail';
$lang->feedback->review            = 'Review';
$lang->feedback->reviewAction      = 'Review Feedback';
$lang->feedback->adminView         = 'Developer Interface';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Close';
$lang->feedback->closeAction       = 'Close Feedback';
$lang->feedback->feelLike          = ' like it!';
$lang->feedback->ask               = 'Doubt';
$lang->feedback->toStory           = 'To ' . $lang->SRCommon;
$lang->feedback->toTask            = 'To Task';
$lang->feedback->toBug             = 'To Bug';
$lang->feedback->toTodo            = 'To Todo';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Todo';
$lang->feedback->task              = 'Task';
$lang->feedback->reply             = 'Reply';
$lang->feedback->replyAction       = 'Reply Feedback';
$lang->feedback->convert           = 'Convert';
$lang->feedback->assign            = 'AssignTo';
$lang->feedback->assignAction      = 'Assign Feedback';
$lang->feedback->export            = 'Export';
$lang->feedback->exportAction      = 'Export Feedback';
$lang->feedback->assignTo          = 'AssignTo';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Delete Feedback';
$lang->feedback->mailNotify        = 'Email Notification';
$lang->feedback->search            = 'Search';
$lang->feedback->comment           = 'Comment';
$lang->feedback->products          = 'Privilege';
$lang->feedback->batchEdit         = 'Batch Edit';
$lang->feedback->batchClose        = 'Batch Close';
$lang->feedback->batchReview       = 'Batch Review';
$lang->feedback->batchAssignTo     = 'Batch Assign';
$lang->feedback->batchChangeModule = 'Batch Change Modules';
$lang->feedback->manageProduct     = 'Manage User Privilege';
$lang->feedback->consumed          = 'Total Cost';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Title';
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Status';
$lang->feedback->subStatus      = 'Sub Status';
$lang->feedback->openedBy       = 'AddedBy';
$lang->feedback->openedDate     = 'Added';
$lang->feedback->processedBy    = 'RepliedBy';
$lang->feedback->processedDate  = 'Replied';
$lang->feedback->reviewedBy     = 'ReviewedBy';
$lang->feedback->reviewedDate   = 'Reviewed';
$lang->feedback->reviewResult   = 'Reviewed Result';
$lang->feedback->reviewedByAB   = 'Reviewer';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Result';
$lang->feedback->assignedTo     = 'AssignedTo';
$lang->feedback->assignedDate   = 'Assigned';
$lang->feedback->closedBy       = 'ClosedBy';
$lang->feedback->closedDate     = 'Closed';
$lang->feedback->closedReason   = 'Close Reason';
$lang->feedback->public         = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'Result';
$lang->feedback->files          = 'Files';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Department';
$lang->feedback->editedBy       = 'ModifiedBy';
$lang->feedback->editedDate     = 'Last Modified';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Unassigned';
$lang->feedback->deptManager    = 'Dept Manager';
$lang->feedback->reviewOpinion  = 'Review Opinion';
$lang->feedback->deleted        = 'Deleted';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select ' . $lang->execution->common;

$lang->feedback->lblBasic       = 'Basic Info';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'AssignedToMe';
$lang->feedback->allProduct     = 'All ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Authorized User';
$lang->feedback->noGrantUser = 'Unauthorized User';
$lang->feedback->hasPrivUser = 'Feedback users have privileges of all products by default. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->tabList['unclosed'] = 'Unclosed';
$lang->feedback->tabList['all']      = 'All';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
$lang->feedback->typeList['issue']       = 'Issue';
$lang->feedback->typeList['risk']        = 'Risk';
$lang->feedback->typeList['opportunity'] = 'Opportunity';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = 'To Be Clarified';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Pending Review';
$lang->feedback->statusList['clarify']    = 'To Be Clarified';
$lang->feedback->statusList['wait']       = 'Waiting';
$lang->feedback->statusList['commenting'] = 'Doing';
$lang->feedback->statusList['replied']    = 'Replied';
$lang->feedback->statusList['asked']      = 'Doubted';
$lang->feedback->statusList['tobug']      = 'Convert to Bug';
$lang->feedback->statusList['tostory']    = 'Convert to ' . $lang->SRCommon;
$lang->feedback->statusList['totask']     = 'Convert to Task';
$lang->feedback->statusList['totodo']     = 'Convert to Todo';
$lang->feedback->statusList['closed']     = 'Closed';

$lang->feedback->closedReasonList[]          = '';
$lang->feedback->closedReasonList['commented'] = 'Replied';
$lang->feedback->closedReasonList['repeat']    = 'Repeat';
$lang->feedback->closedReasonList['refuse']    = 'Reject';

$lang->feedback->solutionList['']        = '';
$lang->feedback->solutionList['tobug']   = 'Convert to Bug';
$lang->feedback->solutionList['tostory'] = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['totask']  = 'Convert to task';
$lang->feedback->solutionList['totodo']  = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Private';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Do you want to delete this feedback?';
$lang->feedback->confirmClose  = 'Do you want to close this feedback?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented        = '$date, replied by <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = '<div>You have no categories.</div>';
$lang->feedback->mustChooseResult = 'Select Result';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, closed by <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, reviewed by <strong>$actor</strong>. The result is <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featurebar = new stdclass();
$lang->feedback->featurebar->unclosed   = 'Unclosed|feedback|admin|browseType=unclosed';
$lang->feedback->featurebar->all        = 'All|feedback|admin|browseType=all';
$lang->feedback->featurebar->public     = 'Public|feedback|admin|browseType=public';
$lang->feedback->featurebar->tostory    = "To {$lang->SRCommon}|feedback|admin|browseType=tostory";
$lang->feedback->featurebar->totask     = 'To Task|feedback|admin|browseType=totask';
$lang->feedback->featurebar->tobug      = 'To Bug|feedback|admin|browseType=tobug';
$lang->feedback->featurebar->totodo     = 'To Todo|feedback|admin|browseType=totodo';
$lang->feedback->featurebar->review     = 'Review|feedback|admin|browseType=review';
$lang->feedback->featurebar->assigntome = 'AssignedToMe|feedback|admin|browseType=assigntome';
$lang->feedback->featurebar->bysearch   = '<i class="icon-search icon"></i> ' . $lang->searchLang . '|feedback|admin|browseType=bysearch';

==> ZenTaoPMS.17.1.php5.4_5.6.zip: zentaopms/extension/biz/feedback/lang/en.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Category';
$lang->feedback->moduleAB          = 'Category';
$lang->feedback->allModule         = 'All Category';
$lang->feedback->manageCate        = 'Manage Category';
$lang->feedback->index             = 'Feedback Home';
$lang->feedback->create            = 'Add Feedback';
$lang->feedback->edit              = 'Edit Feedback';
$lang->feedback->createFaq         = 'Add FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Feedback Interface';
$lang->feedback->browse            = 'Feedback List';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'Feedback Detail';
$lang->feedback->review            = 'Review';
$lang->feedback->reviewAction      = 'Review Feedback';
$lang->feedback->adminView         = 'Developer Interface';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Close';
$lang->feedback->closeAction       = 'Close Feedback';
$lang->feedback->feelLike          = ' like it!';
$lang->feedback->ask               = 'Doubt';
$lang->feedback->toStory           = 'To ' . $lang->SRCommon;
$lang->feedback->toTask            = 'To Task';
$lang->feedback->toBug             = 'To Bug';
$lang->feedback->toTodo            = 'To Todo';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Todo';
$lang->feedback->task              = 'Task';
$lang->feedback->reply             = 'Reply';
$lang->feedback->replyAction       = 'Reply Feedback';
$lang->feedback->convert           = 'Convert';
$lang->feedback->assign            = 'AssignTo';
$lang->feedback->assignAction      = 'Assign Feedback';
$lang->feedback->export            = 'Export';
$lang->feedback->exportAction      = 'Export Feedback';
$lang->feedback->assignTo          = 'AssignTo';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Delete Feedback';
$lang->feedback->mailNotify        = 'Email Notification';
$lang->feedback->search            = 'Search';
$lang->feedback->comment           = 'Comment';
$lang->feedback->products          = 'Privilege';
$lang->feedback->batchEdit         = 'Batch Edit';
$lang->feedback->batchClose        = 'Batch Close';
$lang->feedback->batchReview       = 'Batch Review';
$lang->feedback->batchAssignTo     = 'Batch Assign';
$lang->feedback->batchChangeModule = 'Batch Change Modules';
$lang->feedback->manageProduct     = 'Manage User Privilege';
$lang->feedback->consumed          = 'Total Cost';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Title';
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Status';
$lang->feedback->subStatus      = 'Sub Status';
$lang->feedback->openedBy       = 'AddedBy';
$lang->feedback->openedDate     = 'Added';
$lang->feedback->processedBy    = 'RepliedBy';
$lang->feedback->processedDate  = 'Replied';
$lang->feedback->reviewedBy     = 'ReviewedBy';
$lang->feedback->reviewedDate   = 'Reviewed';
$lang->feedback->reviewResult   = 'Reviewed Result';
$lang->feedback->reviewedByAB   = 'Reviewer';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Result';
$lang->feedback->assignedTo     = 'AssignedTo';
$lang->feedback->assignedDate   = 'Assigned';
$lang->feedback->closedBy       = 'ClosedBy';
$lang->feedback->closedDate     = 'Closed';
$lang->feedback->closedReason   = 'Close Reason';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'Result';
$lang->feedback->files          = 'Files';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Department';
$lang->feedback->editedBy       = 'ModifiedBy';
$lang->feedback->editedDate     = 'Last Modified';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Unassigned';
$lang->feedback->deptManager    = 'Dept Manager';
$lang->feedback->reviewOpinion  = 'Review Opinion';
$lang->feedback->deleted        = 'Deleted';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select ' . $lang->execution->common;

$lang->feedback->lblBasic       = 'Basic Info';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'AssignedToMe';
$lang->feedback->allProduct     = 'All ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Authorized User';
$lang->feedback->noGrantUser = 'Unauthorized User';
$lang->feedback->hasPrivUser = 'Feedback users have privileges of all products by default. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->tabList['unclosed'] = 'Unclosed';
$lang->feedback->tabList['all']      = 'All';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
if($this->config->systemMode == 'new')
{
    $lang->feedback->typeList['issue']       = 'Issue';
    $lang->feedback->typeList['risk']        = 'Risk';
    $lang->feedback->typeList['opportunity'] = 'Opportunity';
}

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = 'To Be Clarified';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Pending Review';
$lang->feedback->statusList['clarify']    = 'To Be Clarified';
$lang->feedback->statusList['wait']       = 'Waiting';
$lang->feedback->statusList['commenting'] = 'Doing';
$lang->feedback->statusList['replied']    = 'Replied';
$lang->feedback->statusList['asked']      = 'Doubted';
$lang->feedback->statusList['tobug']      = 'Convert to Bug';
$lang->feedback->statusList['tostory']    = 'Convert to ' . $lang->SRCommon;
$lang->feedback->statusList['totask']     = 'Convert to Task';
$lang->feedback->statusList['totodo']     = 'Convert to Todo';
$lang->feedback->statusList['closed']     = 'Closed';

$lang->feedback->closedReasonList[]          = '';
$lang->feedback->closedReasonList['commented'] = 'Replied';
$lang->feedback->closedReasonList['repeat']    = 'Repeat';
$lang->feedback->closedReasonList['refuse']    = 'Reject';

$lang->feedback->solutionList['']        = '';
$lang->feedback->solutionList['tobug']   = 'Convert to Bug';
$lang->feedback->solutionList['tostory'] = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['totask']  = 'Convert to task';
$lang->feedback->solutionList['totodo']  = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Private';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Do you want to delete this feedback?';
$lang->feedback->confirmClose  = 'Do you want to close this feedback?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented        = '$date, replied by <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = '<div>You have no categories.</div>';
$lang->feedback->mustChooseResult = 'Select Result';
$lang->feedback->mustInputComment = 'Reply content must be filled in';
$lang->feedback->batchEditTip     = 'Feedback with ID %s is not created by the user and will be ignored automatically';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, closed by <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, reviewed by <strong>$actor</strong>. The result is <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featurebar = new stdclass();
$lang->feedback->featurebar->unclosed   = 'Unclosed|feedback|admin|browseType=unclosed';
$lang->feedback->featurebar->all        = 'All|feedback|admin|browseType=all';
$lang->feedback->featurebar->public     = 'Public|feedback|admin|browseType=public';
$lang->feedback->featurebar->tostory    = "To {$lang->SRCommon}|feedback|admin|browseType=tostory";
$lang->feedback->featurebar->totask     = 'To Task|feedback|admin|browseType=totask';
$lang->feedback->featurebar->tobug      = 'To Bug|feedback|admin|browseType=tobug';
$lang->feedback->featurebar->totodo     = 'To Todo|feedback|admin|browseType=totodo';
$lang->feedback->featurebar->review     = 'Review|feedback|admin|browseType=review';
$lang->feedback->featurebar->assigntome = 'AssignedToMe|feedback|admin|browseType=assigntome';
